---
title: <span class="badge builder"></span> ElasticsearchMetricAggregationWithInlineScriptSettings
---
# <span class="badge builder"></span> ElasticsearchMetricAggregationWithInlineScriptSettings

## Constructor

```python
ElasticsearchMetricAggregationWithInlineScriptSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchMetricAggregationWithInlineScriptSettings
```

### <span class="badge object-method"></span> script

```python
def script(script: cogbuilder.Builder[elasticsearch.InlineScript]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchMetricAggregationWithInlineScriptSettings](./object-ElasticsearchMetricAggregationWithInlineScriptSettings.md)
